@@ -1,6 +1,6 @@
 from .smartwidget import SmartWidget
 from .checkbutton import Checkbutton
-from .combobox import Combobox
+from .combobox import Combobox, CommonCombobox
 from .entry import Entry
 from .labeledscale import LabeledScale
 from .listbox import Listbox
